pycocoa.sets.Set

Package pycocoa :: Module sets :: Class Set |
[frames] | no frames]

# Class Set

      object --+
               |
             set --+
                   |
      object --+   |
               |   |
    bases._Type0 --+
                   |
                  Set

Python `set` Type, wrapping an ObjC `NSMutableSet`.

Instance Methods
copy(self) Make a copy of this set. |
Inherited from `set`: `__and__`, `__cmp__`, `__contains__`, `__eq__`, `__ge__`, `__getattribute__`, `__gt__`, `__iand__`, `__init__`, `__ior__`, `__isub__`, `__iter__`, `__ixor__`, `__le__`, `__len__`, `__lt__`, `__ne__`, `__or__`, `__rand__`, `__reduce__`, `__repr__`, `__ror__`, `__rsub__`, `__rxor__`, `__sizeof__`, `__sub__`, `__xor__`, `add`, `clear`, `difference`, `difference_update`, `discard`, `intersection`, `intersection_update`, `isdisjoint`, `issubset`, `issuperset`, `pop`, `remove`, `symmetric_difference`, `symmetric_difference_update`, `union`, `update` Inherited from `bases._Type0`: `__str__`, `type2strepr` Inherited from `object`: `__delattr__`, `__format__`, `__reduce_ex__`, `__setattr__`, `__subclasshook__`

Static Methods
a new object with type S, a subtype of T |
__new__(cls, ns_set=`[``]`) New Set from a `frozenset`, `list`, `set`, `tuple`, Set or `NSMutableSet`. |

Class Variables
Inherited from `set`: `__hash__`

Properties
| NS Get the ObjC instance (`NSMutableSet`).
Inherited from `bases._Type0`: `NSDelegate`, `typename` Inherited from `object`: `__class__`

Method Details

### __new__(cls, ns_set=`[``]`) Static Method |
New Set from a `frozenset`, `list`, `set`, `tuple`, Set or `NSMutableSet`. Returns: a new object with type S, a subtype of T Overrides: object.__new__

### copy(self) |
Make a copy of this set. Returns: The copy (Set). Overrides: set.copy

Property Details

### NS Get the ObjC instance (`NSMutableSet`). Get Method: NS(self) - Get the ObjC instance (`NSMutableSet`). Set Method: Read_Only(inst, value) - Throws an `AttributeError`, always.